# omicspylib
![pytest](https://github.com/dialectos-ai/omicspylib/actions/workflows/python-app.yml/badge.svg)  ![pytest-nightly](https://github.com/dialectos-ai/omicspylib/actions/workflows/python-nightly-tests.yml/badge.svg) [![Documentation Status](https://readthedocs.org/projects/omicspylib/badge/?version=latest)](https://omicspylib.readthedocs.io/en/latest/?badge=latest)


A python library for omics data analysis.


## Installation
Install the package via `pip`:

```shell
pip install omicspylib
```

## Documentation & Examples
See library's documentation at https://omicspylib.readthedocs.io/en/latest/

Check hands-on tutorials at: https://omicspylib.readthedocs.io/en/latest/tutorials.html

## Reporting Issues
Please use the [GitHub issue](https://github.com/dialectos-ai/omicspylib/issues) tracker to report issues. 
Be sure to include all relevant information to help understand
and reproduce the problem. Including details about your environment,
what you're trying to achieve and the steps to reproduce the issue 
can be very helpful.

## License
Apache License Version 2.0